function [res] = ABCDseries(f,R,C,L);
%ABCDseries - Generate a ABCD matrix corresponding to a serie
%
% Parameter:    f          Frequencies to use
%               R          The serie R
%               C          The serie C
%               L          The serie L
% Returns:      res        The resulting ABCD matrix
%
% Example(s):
%
% Reference:
% 
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2001 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FSAN xDSL simulation tool
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: ABCDseries.m,v 1.1 2001/12/05 15:00:22 tono Exp $
%% ===========================================================================
% Change History
%      2001-11-10 (ToNo) Created
%% ===========================================================================

nf = size(f);

if nargin<4,
    jwL=0;
else
    jwL=j*2*pi*f*L;
end;

if (nargin<3) | (C==0),
    jwC=inf;
else
    jwC=j*2*pi*f*C;
end;

R=R*ones(nf);

Z= R + 1./jwC + jwL;

res{1,1}=ones(nf);
res{1,2}=Z;
res{2,1}=zeros(nf);
res{2,2}=ones(nf);
