function tfplist = fsan_tfplansVDSL(tfplist);
%% ===========================================================================
%fsan_tfplansVDSL(tfplist) - Sets up the tfplan for fsan VDSL tests
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = fsan_tfplanVDSL(ex.tfplist);    Add to existing tfplist
%   tfplan=getList(ex.tfplist,'VDSL-test') ;     Get this VDSL plan
%
%   ex.tfplist = fsan_tfplanVDSL([]);            Create a new tfplist
%   tfplan=getList(ex.tfplist,'VDSL-test');      Get this VDSL plan
%
% Reference:
%    FSAN simulation tool documentation, Telia 1998,1999
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 1999 by Telia Research AB, Lulea, Sweden; All rights reserved. 
% Project       : FSAN xDSL simulation tool
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: fsan_tfplansVDSL.m,v 1.7 2001/09/04 17:53:43 tono Exp $
%% ===========================================================================
% Change History
%      1999-11-04 (ToNo) Created
%      2000-04-05 (UvAn) Added frequency axis for the call to calcPSD
%      2000-04-11 (DaB)  added sync
%      2000-05-26 (UvAn) Added possibillities to fix the bitrate 
%% ===========================================================================

% Default values
def_tfplan.name                  = 'N/A';
def_tfplan.PSD.downstream        = 'N/A';
def_tfplan.PSD.upstream          = 'N/A';
def_tfplan.PSD.active.upstream   = [1 30e6];
def_tfplan.PSD.active.downstream = [1 30e6];
def_tfplan.PSD.PBO.method        = 'None';	
def_tfplan.PSD.PBO.param.len     = 1500;	
def_tfplan.PSD.PBO.param.freq    = 2e6;	
def_tfplan.PSD.PBO.param.maxlen  = 1500;
def_tfplan.PSD.HAM.active        = 1;
def_tfplan.timeDivision.up       = 1;
def_tfplan.timeDivision.down     = 1;
def_tfplan.timeDivision.sync     = 1;
def_tfplan.fixBitrate.name       = 'None';  % Fixed bitrate method
def_tfplan.fixBitrate.active     = 0;       % 0=inactive, 1=active
def_tfplan.fixBitrate.param      = 'N/A';   
def_tfplan.lcname                = 'N/A';


% VDSL TFPlan defintions
% --------------------------
% VDSL Test
tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL-test';
tmp_tfplan.PSD.downstream ='calcPSD([.3e6 -120 .3e6 -60 3.5e6 -60 3.5e6 -120],''Linear'',ex.param.frequency.f)'; 
tmp_tfplan.PSD.upstream   ='calcPSD([3.5e6 -120 3.5e6 -60 11.04e6 -60 11.04e6 -120],''Linear'',ex.param.frequency.f)';	
tmp_tfplan.PSD.PBO.method='None';	% Power back-off method (rl=reference length)
tmp_tfplan.lcname='VDSL-theo';
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL Full Spectra (TDD)
tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL-fullspectra';
tmp_tfplan.PSD.downstream ='calcPSD([1e3 -120 1e3 -60 12e6 -60 12e6 -120],''Linear'',ex.param.frequency.f)'; 
tmp_tfplan.PSD.upstream   = tmp_tfplan.PSD.downstream;	
tmp_tfplan.PSD.PBO.method='None';	% Power back-off method (rl=reference length)
tmp_tfplan.timeDivision.up       = 0.5;
tmp_tfplan.timeDivision.down     = 0.5;
tmp_tfplan.lcname='VDSL-theo';
tfplist=insertList(tfplist,tmp_tfplan);

